==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/notifications/l10n/fi.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Hei %s",
    "Hello %s," : "Hei %s,",
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Voit muuttaa näiden sähköpostien lähetystiheyttä tai ottaa ne pois käytöstä <a href=\"%s\">asetuksissa</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Voit muuttaa näiden sähköpostien lähetystiheyttä tai ottaa ne pois käytöstä asetuksissa:%s",
    "Admin notifications" : "Ylläpitoilmoitukset",
    "Notifications" : "Ilmoitukset",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Taustasovellus ja käyttöliittymä Nextcloudin ilmoitusten ohjelmointirajapinnalle.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Taustasovellus ja käyttöliittymä Nextcloudin ilmoitusten ohjelmointirajapinnalle.\n\t\tSovellukset voivat käyttää ohjelmointirajapintaa lähettämään käyttäjille ilmoituksia selainkäyttöliittymässä sekä synkronoimaan asiakasohjelmia. Esimerkkejä:\n\n📬 Federoidut tiedostojaot: Vastaanotit uuden jaon\n\n📑 Kommentit: Toinen käyttäjä mainitsi sinut tiedostossa olevassa kommentissa\n\n🚢 Päivitysilmoitus: On saatavilla päivitys sovellukseen tai itse Nextcloudiin\n\n📣 Ilmoituskeskus: Ylläpitäjä lähetti tiedotteen",
    "Failed to perform action" : "Toimenpiteen suorittaminen epäonnistui",
    "Dismiss" : "Hylkää",
    "Contact Nextcloud GmbH" : "Ota yhteys Nextcloud GmbH:iin",
    "seconds ago" : "sekuntia sitten",
    "Failed to dismiss notification" : "Ilmoituksen hylkääminen epäonnistui",
    "in {path}" : "polussa {path}",
    "Dismiss all notifications" : "Hylkää kaikki ilmoitukset",
    "Requesting browser permissions to show notifications" : "Pyydetään selaimelta oikeuksia ilmoitusten näyttämiseen",
    "Push notifications might be unreliable" : "Push-ilmoitukset eivät välttämättä ole luotettavia",
    "No notifications" : "Ei ilmoituksia",
    "Failed to dismiss all notifications" : "Kaikki ilmoitusten hylkääminen epäonnistui",
    "You need to set up your email address before you can receive notification emails." : "Aseta sähköpostiosoite, jotta voit vastaanottaa sähköposti-ilmoituksia.",
    "Send email reminders about unhandled notifications after:" : "Lähetä sähköpostimuistutuksia käsittelemättömistä ilmoituksista, kun on kulunut:",
    "Play sound when a new notification arrives" : "Toista ääni kun uusi ilmoitus vastaanotetaan",
    "Play sound when a call started (requires Nextcloud Talk)" : "Toista ääni kun puhelu on aloitettu (vaatii Nextcloud Talkin)",
    "Never" : "Ei koskaan",
    "1 hour" : "1 tunti",
    "3 hours" : "3 tuntia",
    "1 day" : "1 päivä",
    "1 week" : "1 viikko",
    "Your settings have been updated." : "Asetukset on päivitetty.",
    "An error occurred while updating your settings." : "Asetuksia tallentaessa tapahtui virhe."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.16.tar.bz2: nextcloud/apps/notifications/l10n/fi.js <==
OC.L10N.register(
    "notifications",
    {
    "User not found" : "Käyttäjää ei löydy",
    "An unexpected error occurred, ask your administration to check the logs." : "Tapahtui odottamaton virhe, pyydä järjestelmänvalvojaa tarkistamaan lokitiedot.",
    "Hello %s" : "Hei %s",
    "Hello %s," : "Hei %s,",
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Voit muuttaa näiden sähköpostien lähetystiheyttä tai ottaa ne pois käytöstä <a href=\"%s\">asetuksissa</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Voit muuttaa näiden sähköpostien lähetystiheyttä tai ottaa ne pois käytöstä asetuksissa:%s",
    "Admin notifications" : "Ylläpitoilmoitukset",
    "Notifications" : "Ilmoitukset",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Taustasovellus ja käyttöliittymä Nextcloudin ilmoitusten ohjelmointirajapinnalle.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Taustasovellus ja käyttöliittymä Nextcloudin ilmoitusten ohjelmointirajapinnalle.\n\t\tSovellukset voivat käyttää ohjelmointirajapintaa lähettämään käyttäjille ilmoituksia selainkäyttöliittymässä sekä synkronoimaan asiakasohjelmia. Esimerkkejä:\n\n📬 Federoidut tiedostojaot: Vastaanotit uuden jaon\n\n📑 Kommentit: Toinen käyttäjä mainitsi sinut tiedostossa olevassa kommentissa\n\n🚢 Päivitysilmoitus: On saatavilla päivitys sovellukseen tai itse Nextcloudiin\n\n📣 Ilmoituskeskus: Ylläpitäjä lähetti tiedotteen",
    "Failed to perform action" : "Toimenpiteen suorittaminen epäonnistui",
    "Failed to dismiss notification" : "Ilmoituksen hylkääminen epäonnistui",
    "Dismiss" : "Hylkää",
    "Contact Nextcloud GmbH" : "Ota yhteys Nextcloud GmbH:iin",
    "in {path}" : "polussa {path}",
    "Push notifications might be unreliable" : "Push-ilmoitukset eivät välttämättä ole luotettavia",
    "Requesting browser permissions to show notifications" : "Pyydetään selaimelta oikeuksia ilmoitusten näyttämiseen",
    "No notifications" : "Ei ilmoituksia",
    "Failed to dismiss all notifications" : "Kaikki ilmoitusten hylkääminen epäonnistui",
    "Dismiss all notifications" : "Hylkää kaikki ilmoitukset",
    "Never" : "Ei koskaan",
    "1 hour" : "1 tunti",
    "3 hours" : "3 tuntia",
    "1 day" : "1 päivä",
    "1 week" : "1 viikko",
    "Your settings have been updated." : "Asetukset on päivitetty.",
    "An error occurred while updating your settings." : "Asetuksia tallentaessa tapahtui virhe.",
    "Notifications defaults" : "Ilmoitusten oletukset",
    "Send email reminders about unhandled notifications after:" : "Lähetä sähköpostimuistutuksia käsittelemättömistä ilmoituksista, kun on kulunut:",
    "Play sound when a new notification arrives" : "Toista ääni kun uusi ilmoitus vastaanotetaan",
    "Play sound when a call started (requires Nextcloud Talk)" : "Toista ääni kun puhelu on aloitettu (vaatii Nextcloud Talkin)",
    "None" : "Ei mitään",
    "You need to set up your email address before you can receive notification emails." : "Aseta sähköpostiosoite, jotta voit vastaanottaa sähköposti-ilmoituksia.",
    "Select a device" : "Valitse laite",
    "seconds ago" : "sekuntia sitten",
    "Configure the default notification settings for new users" : "Määritä uusien käyttäjien oletusarvoiset ilmoitusasetukset"
},
"nplurals=2; plural=(n != 1);");
